@@ -34,12 +34,13 @@ from nr.collections.generic import Generic
 from nr.databind.core import ObjectMapper, Field, FieldName, Struct, OptionalType
 from nr.databind.json import JsonModule, JsonSerializer
 from nr.interface import Interface, Method as _InterfaceMethod
+from nr.metaclass.deconflict import deconflicted_base
 from nr.pylang.utils import classdef, NotSet
 from nr.sumtype import Constructor, Sumtype, add_constructor_tests
 from typing import Any, BinaryIO, Callable, Dict, List, Optional, TextIO, Type, TypeVar, Union
 
 __author__ = 'Niklas Rosenstein <rosensteinniklas@gmail.com>'
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
 JSON_CONTENT_TYPE = 'application/json'
 PATH_PARAMETER_CONTENT_TYPE = 'x-path-param'
@@ -100,6 +101,13 @@ class ServiceException(Exception):
     return exc
 
 
+class NotFound(ServiceException):
+  http_status_code = 404
+
+  def __init__(self, message: str = None, **kwargs):
+    super().__init__(message, kwargs)
+
+
 class BadRequest(ServiceException):
   http_status_code = 400
 
@@ -158,6 +166,13 @@ class RouteReturn(Sumtype):
   Mapped = Constructor('type_annotation,content_type')
 
 
+class RouteResult:
+
+  def __init__(self, type_: RouteReturn, value: Any) -> None:
+    self.type = type_
+    self.value = value
+
+
 class Path:
   """
   Represents a parametrized path. Parameters are defined by enclosing them
@@ -531,15 +546,15 @@ class ParamVisitor:
     return getattr(self, method_name)(param)
 
 
-class Page(Generic):
+class Page(deconflicted_base(Struct, Generic)):
   """
   Template that represents a paginated type for a specific item type. Can
   be instantiated with the #of() method.
   """
 
   items = Field([Any])
-  next_page_token = Field(Any, FieldName('nextPageToken'))
+  next_page_token = Field(Any, FieldName('nextPageToken'), nullable=True)
 
   def __generic_init__(self, item_type: Any, token_type: Any = int):
-    self.items = Field(item_type)
-    self.next_page_token = Field(token_type, FieldName('nextPageToken'))
+    self.items = Field([item_type])
+    self.next_page_token = Field(token_type, FieldName('nextPageToken'), nullable=True)
